@@ -18,12 +18,16 @@ func TestMatchLanguage(t *testing.T) {
 	c.SetString(language.English, "", "")
 	c.SetString(language.German, "", "")
 
+	saved := DefaultCatalog
+	defer func() { DefaultCatalog = saved }()
+	DefaultCatalog = c
+
 	testCases := []struct {
 		args string // '|'-separated list
 		want string
 	}{{
 		args: "de-CH",
-		want: "de",
+		want: "de-u-rg-chzzzz",
 	}, {
 		args: "bn-u-nu-latn|en-US,en;q=0.9,de;q=0.8,nl;q=0.7",
 		want: "bn-u-nu-latn",
@@ -32,7 +36,6 @@ func TestMatchLanguage(t *testing.T) {
 		want: "en",
 	}}
 	for _, tc := range testCases {
-		DefaultCatalog = c
 		t.Run(tc.args, func(t *testing.T) {
 			got := MatchLanguage(strings.Split(tc.args, "|")...)
 			if got != language.Make(tc.want) {
